// java wrapper for vtkOpenGLRenderer object
//

package vtk;
import vtk.*;

public class vtkOpenGLRenderer extends vtkRenderer
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DeviceRender_2();
  public void DeviceRender()
    { DeviceRender_2(); }

  private native void DeviceRenderOpaqueGeometry_3();
  public void DeviceRenderOpaqueGeometry()
    { DeviceRenderOpaqueGeometry_3(); }

  private native void DeviceRenderTranslucentPolygonalGeometry_4();
  public void DeviceRenderTranslucentPolygonalGeometry()
    { DeviceRenderTranslucentPolygonalGeometry_4(); }

  private native void Clear_5();
  public void Clear()
    { Clear_5(); }

  private native int UpdateLights_6();
  public int UpdateLights()
    { return UpdateLights_6(); }

  private native int GetDepthPeelingHigherLayer_7();
  public int GetDepthPeelingHigherLayer()
    { return GetDepthPeelingHigherLayer_7(); }

  private native boolean HaveApplePrimitiveIdBug_8();
  public boolean HaveApplePrimitiveIdBug()
    { return HaveApplePrimitiveIdBug_8(); }

  private native boolean HaveAppleQueryAllocationBug_9();
  public boolean HaveAppleQueryAllocationBug()
    { return HaveAppleQueryAllocationBug_9(); }

  private native boolean IsDualDepthPeelingSupported_10();
  public boolean IsDualDepthPeelingSupported()
    { return IsDualDepthPeelingSupported_10(); }

  public vtkOpenGLRenderer() { super(); }

  public vtkOpenGLRenderer(long id) { super(id); }
  public native long   VTKInit();

}
